cv.models.managers — Django-Vitae 0.0.1 documentation

# `cv.models.managers`

class `cv.models.managers.` `DisplayManager`

  Returns displayable objects from models.

  `get_queryset`()

    Return objects for which field `display` has been set to `True`.

class `cv.models.managers.` `PublicationManager`

  Class to manage publications.

  This class subclasses `DisplayManager` and includes the default queryset of all displayable objects. In addition, it provides three methods: `published`, `revise`, and `inprep` to return querysets of publications at stages in the publication process.

  `published`()

    Return queryset of articles accepted for publication or published.

  `revise`()

    Return queryset of articles in revision process.

  `inprep`()

    Return queryset of articles being prepared for submission.

class `cv.models.managers.` `GrantManager`

  Class to manage grants.

  This class subclasses `DisplayManager` and includes the default queryset of all displayable objects. In addition, it provides two methods: `internal_grants` and `external_grants` for different grant sources.

class `cv.models.managers.` `ServiceManager`

  Class to manage service work.

  This class subclasses `DisplayManager` and includes the default queryset of all displayable objects. In addition, it provides three methods: `department_services`, `university services`, and `discipline_services` for service work to different institutions.

class `cv.models.managers.` `PrimaryPositionManager`

  Manages positions used in heading of CV.

  Returns a queryset of positions in which `primary_position` has been set to `True`.

  `get_queryset`()

    Return a new QuerySet object. Subclasses can override this method to customize the behavior of the Manager.